@@ -2,5 +2,5 @@ def test_compile():
     try:
         import tiddlywebplugins.twimport
         assert True
-    except ImportError, exc:
+    except ImportError as exc:
         assert False, exc
